pub struct InfluxDbConfig {Show 16 fields
pub default_namespace: Option<String>,
pub endpoint: HttpEndpoint,
pub version: Option<InfluxDbVersion>,
pub database: Option<String>,
pub consistency: Option<String>,
pub retention_policy_name: Option<String>,
pub username: Option<String>,
pub password: Option<SensitiveString>,
pub org: Option<String>,
pub bucket: Option<String>,
pub token: Option<SensitiveString>,
pub batch: BatchConfig<InfluxDbDefaultBatchSettings>,
pub request: TowerRequestConfig,
pub tags: Option<HashMap<String, String>>,
pub tls: Option<TlsConfig>,
pub quantiles: Vec<f64>,
/* private fields */
}Expand description
Configuration for the influxdb_metrics sink.
Fields
default_namespace: Option<String>Sets the default namespace for any metrics sent.
This namespace is only used if a metric has no existing namespace. When a namespace is
present, it is used as a prefix to the metric name, and separated with a period (.).
endpoint: HttpEndpointThe endpoint to send data to.
This should be a full HTTP URI, including the scheme, host, and port.
version: Option<InfluxDbVersion>The InfluxDB API version to use.
Omitting this option is deprecated and it will be required in a future release. When unset, the version is temporarily inferred from the configured settings.
database: Option<String>The name of the database to write into.
Only relevant when using InfluxDB v0.x/v1.x.
consistency: Option<String>The consistency level to use for writes.
Only relevant when using InfluxDB v0.x/v1.x.
retention_policy_name: Option<String>The target retention policy for writes.
Only relevant when using InfluxDB v0.x/v1.x.
username: Option<String>The username to authenticate with.
Only relevant when using InfluxDB v0.x/v1.x.
password: Option<SensitiveString>The password to authenticate with.
Only relevant when using InfluxDB v0.x/v1.x.
org: Option<String>The name of the organization to write into.
Only relevant when using InfluxDB v2.x and above.
bucket: Option<String>The name of the bucket to write into.
Only relevant when using InfluxDB v2.x and above.
token: Option<SensitiveString>The token to authenticate with.
Only relevant when using InfluxDB v2.x and above.
batch: BatchConfig<InfluxDbDefaultBatchSettings>request: TowerRequestConfigA map of additional tags, in the key/value pair format, to add to each measurement.
tls: Option<TlsConfig>quantiles: Vec<f64>The list of quantiles to calculate when sending distribution metrics.